==> duiba-live-center-api-0.0.18-4-20201123.060925-1-sources.jar: cn/com/duiba/kjy/livecenter/api/remoteservice/RemoteLiveTeamService.java <==
package cn.com.duiba.kjy.livecenter.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveCompanyTeamDto;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveCompanyTeamNameDto;
import cn.com.duiba.kjy.livecenter.api.param.company.LiveCompanyTeamSearchParam;
import cn.com.duiba.kjy.livecenter.api.param.team.LiveTeamEsSearchParam;
import org.apache.commons.lang3.tuple.Pair;

import java.util.List;
import java.util.Map;

/**
 * 直播公司团队服务
 * @author 周舟
 * @date 2020-3-28 10:22:31
 * @version 1.0
 */
@AdvancedFeignClient
public interface RemoteLiveTeamService {

    /**
     * 根据条件查询列表
     * @param searchParam
     * @return
     */
    List<LiveCompanyTeamDto> findByCondition(LiveCompanyTeamSearchParam searchParam);

    /**
     * 根据条件统计
     * @param searchParam
     * @return
     */
    Integer countByCondition(LiveCompanyTeamSearchParam searchParam);

    /**
     * 根据公司id 统计当前公司下的成员总数
     * @param companyId
     * @return
     */
    Integer getAgentCountByCompanyId(Long companyId);

    /**
     * 统计公司下团队id  对应团队成员数量
     * @param teamIds
     * @return
     */
    Map<Long,Integer> getTeamId2AgentNumMap(List<Long> teamIds);

    /**
     * 保存更新直播公司团队
     * @param dto 直播公司团队
     * @return 主键，为0，说明新增失败
     */
    Long saveAndUpdate(LiveCompanyTeamDto dto);

    /**
     * 根据id查询
     * @param id 主键id
     * @return 直播公司团队
     */
    LiveCompanyTeamDto findById(Long id);

    /**
     * 根据id批量查询
     * @param ids 主键id列表
     * @return 直播公司团队
     */
    List<LiveCompanyTeamDto> findByIds(List<Long> ids);

    /**
     * 查询团队名称
     * @param ids 团队主键集合
     * @return key：团队主键，value：团队名称
     */
    Map<Long, String> findTeamNameMap(List<Long> ids);

    /**
     * 根据id删除
     * @param id 主键id
     * @return 是否成功 1 成功 其他失败
     */
    Integer deleteById(Long id);

    /**
     * 根据公司id和团队名称获取团队信息，最多返回200条
     *
     * @param companyId 公司id
     * @param teamName 团队名称
     * @return 团队名称信息
     */
    List<LiveCompanyTeamNameDto> findByCompanyIdAndTeamName(Long companyId, String teamName);

    /**
     * 批量插入团队信息
     *
     * @param dtoList 团队信息集合
     * @return 执行结果
     */
    int batchInsert(List<LiveCompanyTeamDto> dtoList);

    /**
     * 根据公司id和团队名称集合批量查询
     *
     * @param companyId 公司id
     * @param teamNames 团队名称集合
     * @return 团队名称信息
     */
    List<LiveCompanyTeamNameDto> findByCompanyIdAndTeamNames(Long companyId, List<String> teamNames);

    /**
     * 保存并获取团队信息
     * @deprecated 废弃 有需要使用batchInsertAndGet
     * @param companyId 公司id
     * @param teamNames 团队名称
     * @return 团队信息
     */
    @Deprecated
    List<LiveCompanyTeamNameDto> batchSaveAndGet(Long companyId, List<String> teamNames);

    /**
     * 批量插入并返回团队信息
     *
     * @param dtoList 团心信息集合
     * @return 团队信息集合
     */
    List<LiveCompanyTeamNameDto> batchInsertAndGet(List<LiveCompanyTeamDto> dtoList);

    /**
     * 从es中查询团队列表
     * @return es查询结果
     */
    Pair<Long, List<LiveCompanyTeamNameDto>> searchTeamFromEs(LiveTeamEsSearchParam param);
}

==> duiba-live-center-api-0.0.44-20210411.134529-2-sources.jar: cn/com/duiba/kjy/livecenter/api/remoteservice/RemoteLiveTeamService.java <==
package cn.com.duiba.kjy.livecenter.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveCompanyTeamDto;
import cn.com.duiba.kjy.livecenter.api.dto.company.LiveCompanyTeamNameDto;
import cn.com.duiba.kjy.livecenter.api.param.company.LiveCompanyTeamSearchParam;
import cn.com.duiba.kjy.livecenter.api.param.team.LiveTeamEsSearchParam;
import cn.com.duiba.kjy.livecenter.api.param.team.TeamBatchDeleteParam;
import org.apache.commons.lang3.tuple.Pair;

import java.util.List;
import java.util.Map;

/**
 * 直播公司团队服务
 * @author 周舟
 * @date 2020-3-28 10:22:31
 * @version 1.0
 */
@AdvancedFeignClient
public interface RemoteLiveTeamService {

    /**
     * 根据条件查询列表
     * @param searchParam
     * @return
     */
    List<LiveCompanyTeamDto> findByCondition(LiveCompanyTeamSearchParam searchParam);

    /**
     * 根据条件统计
     * @param searchParam
     * @return
     */
    Integer countByCondition(LiveCompanyTeamSearchParam searchParam);

    /**
     * 根据公司id 统计当前公司下的成员总数
     * @param companyId
     * @return
     */
    Integer getAgentCountByCompanyId(Long companyId);

    /**
     * 统计公司下团队id  对应团队成员数量
     * @param teamIds
     * @return
     */
    Map<Long,Integer> getTeamId2AgentNumMap(List<Long> teamIds);

    /**
     * 保存更新直播公司团队
     * @param dto 直播公司团队
     * @return 主键，为0，说明新增失败
     */
    Long saveAndUpdate(LiveCompanyTeamDto dto);

    /**
     * 根据id查询
     * @param id 主键id
     * @return 直播公司团队
     */
    LiveCompanyTeamDto findById(Long id);

    /**
     * 根据id批量查询
     * @param ids 主键id列表
     * @return 直播公司团队
     */
    List<LiveCompanyTeamDto> findByIds(List<Long> ids);

    /**
     * 查询团队名称
     * @param ids 团队主键集合
     * @return key：团队主键，value：团队名称
     */
    Map<Long, String> findTeamNameMap(List<Long> ids);

    /**
     * 根据id删除
     * @param id 主键id
     * @return 是否成功 1 成功 其他失败
     */
    Integer deleteById(Long id);

    /**
     * 根据公司id和团队名称获取团队信息，最多返回200条
     *
     * @param companyId 公司id
     * @param teamName 团队名称
     * @return 团队名称信息
     */
    List<LiveCompanyTeamNameDto> findByCompanyIdAndTeamName(Long companyId, String teamName);

    /**
     * 批量插入团队信息
     *
     * @param dtoList 团队信息集合
     * @return 执行结果
     */
    int batchInsert(List<LiveCompanyTeamDto> dtoList);

    /**
     * 根据公司id和团队名称集合批量查询
     *
     * @param companyId 公司id
     * @param teamNames 团队名称集合
     * @return 团队名称信息
     */
    List<LiveCompanyTeamNameDto> findByCompanyIdAndTeamNames(Long companyId, List<String> teamNames);

    /**
     * 保存并获取团队信息
     * @deprecated 废弃 有需要使用batchInsertAndGet
     * @param companyId 公司id
     * @param teamNames 团队名称
     * @return 团队信息
     */
    @Deprecated
    List<LiveCompanyTeamNameDto> batchSaveAndGet(Long companyId, List<String> teamNames);

    /**
     * 批量插入并返回团队信息
     *
     * @param dtoList 团心信息集合
     * @return 团队信息集合
     */
    List<LiveCompanyTeamNameDto> batchInsertAndGet(List<LiveCompanyTeamDto> dtoList);

    /**
     * 从es中查询团队列表
     * @return es查询结果
     */
    Pair<Long, List<LiveCompanyTeamNameDto>> searchTeamFromEs(LiveTeamEsSearchParam param);

    /**
     * 批量删除团队
     * @param param
     * @return
     */
    Integer batchDelete(TeamBatchDeleteParam param);
}
